"""EDF+,BDF module for conversion to FIF."""

# Author: Teon Brooks <teon.brooks@gmail.com>
#
# License: BSD (3-clause)

from .edf import read_raw_edf, read_raw_bdf, read_raw_gdf
